@@ -21,7 +21,7 @@ use Text::Tabs;
 
 use vars qw($VERSION);
 #$VERSION = sprintf '4.%03d', q$Revision: #24 $ =~ /\D(\d+)\s*$/;
-$VERSION = '4.029';
+$VERSION = '4.030';
 
 use Tk qw(Ev $XS_VERSION);
 use base  qw(Tk::Clipboard Tk::Widget);
@@ -61,6 +61,8 @@ sub bindRdOnly
  $mw->bind($class,'<Meta-B1-Motion>','NoOp');
  $mw->bind($class,'<Meta-1>','NoOp');
  $mw->bind($class,'<Alt-KeyPress>','NoOp');
+ $mw->bind($class,'<Meta-KeyPress>','NoOp');
+ $mw->bind($class,'<Control-KeyPress>','NoOp');
  $mw->bind($class,'<Escape>','unselectAll');
 
  $mw->bind($class,'<1>',['Button1',Ev('x'),Ev('y')]);
