@@ -1,7 +1,9 @@
 #include "Lang.h"
 #include "Lang_f.h"
+static unsigned LangVSize(void) { return sizeof(LangVtab);}
 static LangVtab LangVtable =
 {
+ LangVSize,
 #define VFUNC(type,name,mem,args) name,
 #define VVAR(type,name,mem)      &name,
 #include "Lang.t"
