@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkCanvPs.c,v 1.10 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkCanvPs.c,v 1.13 2003/02/18 21:54:18 hobbs Exp $
  */
 #include "tkInt.h"
 #include "tkCanvas.h"
@@ -20,6 +20,20 @@
  * See tkCanvas.h for key data structures used to implement canvases.
  */
 
+/*
+ * The following definition is used in generating postscript for images
+ * and windows.
+ */
+
+typedef struct TkColormapData {	/* Hold color information for a window */
+    int separated;		/* Whether to use separate color bands */
+    int color;			/* Whether window is color or black/white */
+    int ncolors;		/* Number of color values stored */
+    XColor *colors;		/* Pixel value -> RGB mappings */
+    int red_mask, green_mask, blue_mask;	/* Masks and shifts for each */
+    int red_shift, green_shift, blue_shift;	/* color band */
+} TkColormapData;
+
 /*
  * One of the following structures is created to keep track of Postscript
  * output being generated.  It consists mostly of information provided on
@@ -461,13 +475,14 @@ TkCanvPostscriptCmd(canvasPtr, interp, argc, argv)
     /*
      * Insert the prolog
      */
-    Tcl_AppendResult(interp, Tcl_GetVar(interp,"::tk::ps_preamable",TCL_GLOBAL_ONLY), (char *) NULL);
+    Tcl_AppendResult(interp, Tcl_GetVar(interp,"::tk::ps_preamable",
+	    TCL_GLOBAL_ONLY), (char *) NULL);
+
     if (psInfo.chan != NULL) {
         Tcl_Write(psInfo.chan, Tcl_GetStringResult(interp), -1);
 	Tcl_ResetResult(canvasPtr->interp);
     }
 
-
     /*
      *-----------------------------------------------------------
      * Document setup:  set the color level and include fonts.
@@ -661,7 +676,7 @@ Tk_PostscriptColor(interp, psInfo, colorPtr)
      */
 
     if (psInfoPtr->colorVar != NULL) {
-	Arg cmdString;
+	Tcl_Obj * cmdString;
 	Tcl_Obj *name = Tcl_NewStringObj(Tk_NameOfColor(colorPtr),-1);
 
 	cmdString = Tcl_ObjGetVar2(interp, psInfoPtr->colorVar, name,0);
@@ -1109,6 +1124,12 @@ GetPostscriptPoints(interp, string, doublePtr)
  *      data passed as an argument, and should work for all Visual
  *      types.
  *
+ *	This implementation is bogus on Windows because the colormap
+ *	data is never filled in.  Instead all postscript generated
+ *	data coming through here is expected to be RGB color data.
+ *	To handle lower bit-depth images properly, XQueryColors
+ *	must be implemented for Windows.
+ *
  * Results:
  *	Returns red, green, and blue color values in the range
  *      0 to 1.  There are no error returns.
@@ -1118,7 +1139,27 @@ GetPostscriptPoints(interp, string, doublePtr)
  *
  *--------------------------------------------------------------
  */
+#ifdef WIN32
+#include <windows.h>
 
+/*
+ * We could just define these instead of pulling in windows.h.
+ #define GetRValue(rgb)	((BYTE)(rgb))
+ #define GetGValue(rgb)	((BYTE)(((WORD)(rgb)) >> 8))
+ #define GetBValue(rgb)	((BYTE)((rgb)>>16))
+*/
+
+static void
+TkImageGetColor(cdata, pixel, red, green, blue)
+    TkColormapData *cdata;              /* Colormap data */
+    unsigned long pixel;                /* Pixel value to look up */
+    double *red, *green, *blue;         /* Color data to return */
+{
+    *red   = (double) GetRValue(pixel) / 255.0;
+    *green = (double) GetGValue(pixel) / 255.0;
+    *blue  = (double) GetBValue(pixel) / 255.0;
+}
+#else
 static void
 TkImageGetColor(cdata, pixel, red, green, blue)
     TkColormapData *cdata;              /* Colormap data */
@@ -1129,15 +1170,16 @@ TkImageGetColor(cdata, pixel, red, green, blue)
 	int r = (pixel & cdata->red_mask) >> cdata->red_shift;
 	int g = (pixel & cdata->green_mask) >> cdata->green_shift;
 	int b = (pixel & cdata->blue_mask) >> cdata->blue_shift;
-	*red = cdata->colors[r].red / 65535.0;
+	*red   = cdata->colors[r].red / 65535.0;
 	*green = cdata->colors[g].green / 65535.0;
-	*blue = cdata->colors[b].blue / 65535.0;
+	*blue  = cdata->colors[b].blue / 65535.0;
     } else {
-	*red = cdata->colors[pixel].red / 65535.0;
+	*red   = cdata->colors[pixel].red / 65535.0;
 	*green = cdata->colors[pixel].green / 65535.0;
-	*blue = cdata->colors[pixel].blue / 65535.0;
+	*blue  = cdata->colors[pixel].blue / 65535.0;
     }
 }
+#endif
 
 /*
  *--------------------------------------------------------------
@@ -1178,7 +1220,7 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
     int bytesPerLine=0, maxWidth=0;
     int level = psInfoPtr->colorLevel;
     Colormap cmap;
-    int i, depth, ncolors;
+    int i, ncolors;
     Visual *visual;
     TkColormapData cdata;
 
@@ -1187,7 +1229,6 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
     }
 
     cmap = Tk_Colormap(tkwin);
-    depth = Tk_Depth(tkwin);
     visual = Tk_Visual(tkwin);
 
     /*
@@ -1229,7 +1270,6 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
     else
 	cdata.color = 1;
 
-
     XQueryColors(Tk_Display(tkwin), cmap, cdata.colors, ncolors);
 
     /*
@@ -1252,8 +1292,7 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
      * Postscript interpreter).
      */
 
-    switch (level)
-    {
+    switch (level) {
 	case 0: bytesPerLine = (width + 7) / 8;  maxWidth = 240000;  break;
 	case 1: bytesPerLine = width;  maxWidth = 60000;  break;
 	case 2: bytesPerLine = 3 * width;  maxWidth = 20000;  break;
@@ -1334,9 +1373,7 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
 			TkImageGetColor(&cdata, XGetPixel(ximage, xx, yy),
 					&red, &green, &blue);
 			sprintf(buffer, "%02X", (int) floor(0.5 + 255.0 *
-							    (0.30 * red +
-							     0.59 * green +
-							     0.11 * blue)));
+				(0.30 * red + 0.59 * green + 0.11 * blue)));
 			Tcl_AppendResult(interp, buffer, (char *) NULL);
 			lineLen += 2;
 			if (lineLen > 60) {
@@ -1351,7 +1388,7 @@ TkPostscriptImage(interp, tkwin, psInfo, ximage, x, y, width, height)
 		     * Finally, color mode.  Here, just output the red, green,
 		     * and blue values directly.
 		     */
-			for (xx = x; xx < x+width; xx++) {
+		    for (xx = x; xx < x+width; xx++) {
 			TkImageGetColor(&cdata, XGetPixel(ximage, xx, yy),
 				&red, &green, &blue);
 			sprintf(buffer, "%02X%02X%02X",
