@@ -1,9 +1,9 @@
 /*
  * tkCursor.c --
  *
- *	This file maintains a database of read-only cursors for the Tk
- *	toolkit.  This allows cursors to be shared between widgets and
- *	also avoids round-trips to the X server.
+ *      This file maintains a database of read-only cursors for the Tk
+ *      toolkit.  This allows cursors to be shared between widgets and
+ *      also avoids round-trips to the X server.
  *
  * Copyright (c) 1990-1994 The Regents of the University of California.
  * Copyright (c) 1994-1997 Sun Microsystems, Inc.
@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkCursor.c,v 1.9 2002/08/05 04:30:38 dgp Exp $
+ * RCS: @(#) $Id: tkCursor.c,v 1.9.2.1 2003/04/18 21:56:59 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -26,29 +26,29 @@
  */
 
 typedef struct {
-    CONST char *source;		/* Cursor bits. */
-    CONST char *mask;		/* Mask bits. */
-    int width, height;		/* Dimensions of cursor (and data
+    CONST char *source;         /* Cursor bits. */
+    CONST char *mask;           /* Mask bits. */
+    int width, height;          /* Dimensions of cursor (and data
 				 * and mask). */
-    int xHot, yHot;		/* Location of cursor hot-spot. */
-    Tk_Uid fg, bg;		/* Colors for cursor. */
-    Display *display;		/* Display on which cursor will be used. */
+    int xHot, yHot;             /* Location of cursor hot-spot. */
+    Tk_Uid fg, bg;              /* Colors for cursor. */
+    Display *display;           /* Display on which cursor will be used. */
 } DataKey;
 
 /*
  * Forward declarations for procedures defined in this file:
  */
 
-static void		CursorInit _ANSI_ARGS_((TkDisplay *dispPtr));
-static void		DupCursorObjProc _ANSI_ARGS_((Tcl_Obj *srcObjPtr,
+static void             CursorInit _ANSI_ARGS_((TkDisplay *dispPtr));
+static void             DupCursorObjProc _ANSI_ARGS_((Tcl_Obj *srcObjPtr,
 			    Tcl_Obj *dupObjPtr));
-static void		FreeCursor _ANSI_ARGS_((TkCursor *cursorPtr));
-static void		FreeCursorObjProc _ANSI_ARGS_((Tcl_Obj *objPtr));
-static TkCursor *	GetCursor _ANSI_ARGS_((Tcl_Interp *interp,
+static void             FreeCursor _ANSI_ARGS_((TkCursor *cursorPtr));
+static void             FreeCursorObjProc _ANSI_ARGS_((Tcl_Obj *objPtr));
+static TkCursor *       TkcGetCursor _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin, CONST char *name));
-static TkCursor *	GetCursorFromObj _ANSI_ARGS_((Tk_Window tkwin,
+static TkCursor *       GetCursorFromObj _ANSI_ARGS_((Tk_Window tkwin,
 			    Tcl_Obj *objPtr));
-static void		InitCursorObj _ANSI_ARGS_((Tcl_Obj *objPtr));
+static void             InitCursorObj _ANSI_ARGS_((Tcl_Obj *objPtr));
 
 /*
  * The following structure defines the implementation of the "cursor" Tcl
@@ -59,11 +59,11 @@ static void		InitCursorObj _ANSI_ARGS_((Tcl_Obj *objPtr));
  */
 
 Tcl_ObjType tkCursorObjType = {
-    "cursor",			/* name */
-    FreeCursorObjProc,		/* freeIntRepProc */
-    DupCursorObjProc,		/* dupIntRepProc */
-    NULL,			/* updateStringProc */
-    NULL			/* setFromAnyProc */
+    "cursor",                   /* name */
+    FreeCursorObjProc,          /* freeIntRepProc */
+    DupCursorObjProc,           /* dupIntRepProc */
+    NULL,                       /* updateStringProc */
+    NULL                        /* setFromAnyProc */
 };
 
 /*
@@ -71,31 +71,31 @@ Tcl_ObjType tkCursorObjType = {
  *
  * Tk_AllocCursorFromObj --
  *
- *	Given a Tcl_Obj *, map the value to a corresponding
- *	Tk_Cursor structure based on the tkwin given.
+ *      Given a Tcl_Obj *, map the value to a corresponding
+ *      Tk_Cursor structure based on the tkwin given.
  *
  * Results:
- *	The return value is the X identifer for the desired cursor,
- *	unless objPtr couldn't be parsed correctly.  In this case,
- *	None is returned and an error message is left in the interp's result.
- *	The caller should never modify the cursor that is returned, and
- *	should eventually call Tk_FreeCursorFromObj when the cursor is no
- *	longer needed.
+ *      The return value is the X identifer for the desired cursor,
+ *      unless objPtr couldn't be parsed correctly.  In this case,
+ *      None is returned and an error message is left in the interp's result.
+ *      The caller should never modify the cursor that is returned, and
+ *      should eventually call Tk_FreeCursorFromObj when the cursor is no
+ *      longer needed.
  *
  * Side effects:
- *	The cursor is added to an internal database with a reference count.
- *	For each call to this procedure, there should eventually be a call
- *	to Tk_FreeCursorFromObj, so that the database can be cleaned up
- *	when cursors aren't needed anymore.
+ *      The cursor is added to an internal database with a reference count.
+ *      For each call to this procedure, there should eventually be a call
+ *      to Tk_FreeCursorFromObj, so that the database can be cleaned up
+ *      when cursors aren't needed anymore.
  *
  *----------------------------------------------------------------------
  */
 
 Tk_Cursor
 Tk_AllocCursorFromObj(interp, tkwin, objPtr)
-    Tcl_Interp *interp;		/* Interp for error results. */
-    Tk_Window tkwin;		/* Window in which the cursor will be used.*/
-    Tcl_Obj *objPtr;		/* Object describing cursor; see manual
+    Tcl_Interp *interp;         /* Interp for error results. */
+    Tk_Window tkwin;            /* Window in which the cursor will be used.*/
+    Tcl_Obj *objPtr;            /* Object describing cursor; see manual
 				 * entry for description of legal
 				 * syntax of this obj's string rep. */
 {
@@ -147,11 +147,11 @@ Tk_AllocCursorFromObj(interp, tkwin, objPtr)
     }
 
     /*
-     * Still no luck.  Call GetCursor to allocate a new TkCursor object.
+     * Still no luck.  Call TkcGetCursor to allocate a new TkCursor object.
      */
 
-    cursorPtr = GetCursor(interp, tkwin, Tcl_GetString(objPtr));
-    TclObjInternal(objPtr)->twoPtrValue.ptr1 = (VOID *) cursorPtr;
+    cursorPtr = TkcGetCursor(interp, tkwin, Tcl_GetString(objPtr));
+    objPtr->internalRep.twoPtrValue.ptr1 = (VOID *) cursorPtr;
     if (cursorPtr == NULL) {
 	return None;
     } else {
@@ -165,34 +165,34 @@ Tk_AllocCursorFromObj(interp, tkwin, objPtr)
  *
  * Tk_GetCursor --
  *
- *	Given a string describing a cursor, locate (or create if necessary)
- *	a cursor that fits the description.
+ *      Given a string describing a cursor, locate (or create if necessary)
+ *      a cursor that fits the description.
  *
  * Results:
- *	The return value is the X identifer for the desired cursor,
- *	unless string couldn't be parsed correctly.  In this case,
- *	None is returned and an error message is left in the interp's result.
- *	The caller should never modify the cursor that is returned, and
- *	should eventually call Tk_FreeCursor when the cursor is no longer
- *	needed.
+ *      The return value is the X identifer for the desired cursor,
+ *      unless string couldn't be parsed correctly.  In this case,
+ *      None is returned and an error message is left in the interp's result.
+ *      The caller should never modify the cursor that is returned, and
+ *      should eventually call Tk_FreeCursor when the cursor is no longer
+ *      needed.
  *
  * Side effects:
- *	The cursor is added to an internal database with a reference count.
- *	For each call to this procedure, there should eventually be a call
- *	to Tk_FreeCursor, so that the database can be cleaned up when cursors
- *	aren't needed anymore.
+ *      The cursor is added to an internal database with a reference count.
+ *      For each call to this procedure, there should eventually be a call
+ *      to Tk_FreeCursor, so that the database can be cleaned up when cursors
+ *      aren't needed anymore.
  *
  *----------------------------------------------------------------------
  */
 
 Tk_Cursor
 Tk_GetCursor(interp, tkwin, string)
-    Tcl_Interp *interp;		/* Interpreter to use for error reporting. */
-    Tk_Window tkwin;		/* Window in which cursor will be used. */
-    Tk_Uid string;		/* Description of cursor.  See manual entry
+    Tcl_Interp *interp;         /* Interpreter to use for error reporting. */
+    Tk_Window tkwin;            /* Window in which cursor will be used. */
+    Tk_Uid string;              /* Description of cursor.  See manual entry
 				 * for details on legal syntax. */
 {
-    TkCursor *cursorPtr = GetCursor(interp, tkwin, string);
+    TkCursor *cursorPtr = TkcGetCursor(interp, tkwin, string);
     if (cursorPtr == NULL) {
 	return None;
     }
@@ -202,35 +202,35 @@ Tk_GetCursor(interp, tkwin, string)
 /*
  *----------------------------------------------------------------------
  *
- * GetCursor --
+ * TkcGetCursor --
  *
- *	Given a string describing a cursor, locate (or create if necessary)
- *	a cursor that fits the description. This routine returns the
- *	internal data structure for the cursor, which avoids extra
- *	hash table lookups in Tk_AllocCursorFromObj.
+ *      Given a string describing a cursor, locate (or create if necessary)
+ *      a cursor that fits the description. This routine returns the
+ *      internal data structure for the cursor, which avoids extra
+ *      hash table lookups in Tk_AllocCursorFromObj.
  *
  * Results:
- *	The return value is a pointer to the TkCursor for the desired
- *	cursor, unless string couldn't be parsed correctly.  In this
- *	case, NULL is returned and an error message is left in the
- *	interp's result. The caller should never modify the cursor that
- *	is returned, and should eventually call Tk_FreeCursor when the
- *	cursor is no longer needed.
+ *      The return value is a pointer to the TkCursor for the desired
+ *      cursor, unless string couldn't be parsed correctly.  In this
+ *      case, NULL is returned and an error message is left in the
+ *      interp's result. The caller should never modify the cursor that
+ *      is returned, and should eventually call Tk_FreeCursor when the
+ *      cursor is no longer needed.
  *
  * Side effects:
- *	The cursor is added to an internal database with a reference count.
- *	For each call to this procedure, there should eventually be a call
- *	to Tk_FreeCursor, so that the database can be cleaned up when cursors
- *	aren't needed anymore.
+ *      The cursor is added to an internal database with a reference count.
+ *      For each call to this procedure, there should eventually be a call
+ *      to Tk_FreeCursor, so that the database can be cleaned up when cursors
+ *      aren't needed anymore.
  *
  *----------------------------------------------------------------------
  */
 
 static TkCursor *
-GetCursor(interp, tkwin, string)
-    Tcl_Interp *interp;		/* Interpreter to use for error reporting. */
-    Tk_Window tkwin;		/* Window in which cursor will be used. */
-    CONST char *string;		/* Description of cursor.  See manual entry
+TkcGetCursor(interp, tkwin, string)
+    Tcl_Interp *interp;         /* Interpreter to use for error reporting. */
+    Tk_Window tkwin;            /* Window in which cursor will be used. */
+    CONST char *string;         /* Description of cursor.  See manual entry
 				 * for details on legal syntax. */
 {
     Tcl_HashEntry *nameHashPtr;
@@ -244,7 +244,7 @@ GetCursor(interp, tkwin, string)
     }
 
     nameHashPtr = Tcl_CreateHashEntry(&dispPtr->cursorNameTable,
-            string, &new);
+	    string, &new);
     if (!new) {
 	existingCursorPtr = (TkCursor *) Tcl_GetHashValue(nameHashPtr);
 	for (cursorPtr = existingCursorPtr; cursorPtr != NULL;
@@ -278,7 +278,7 @@ GetCursor(interp, tkwin, string)
     cursorPtr->hashPtr = nameHashPtr;
     cursorPtr->nextPtr = existingCursorPtr;
     cursorPtr->idHashPtr = Tcl_CreateHashEntry(&dispPtr->cursorIdTable,
-            (char *) cursorPtr->cursor, &new);
+	    (char *) cursorPtr->cursor, &new);
     if (!new) {
 	panic("cursor already registered in Tk_GetCursor");
     }
@@ -293,22 +293,22 @@ GetCursor(interp, tkwin, string)
  *
  * Tk_GetCursorFromData --
  *
- *	Given a description of the bits and colors for a cursor,
- *	make a cursor that has the given properties.
+ *      Given a description of the bits and colors for a cursor,
+ *      make a cursor that has the given properties.
  *
  * Results:
- *	The return value is the X identifer for the desired cursor,
- *	unless it couldn't be created properly.  In this case, None is
- *	returned and an error message is left in the interp's result.  The
- *	caller should never modify the cursor that is returned, and
- *	should eventually call Tk_FreeCursor when the cursor is no
- *	longer needed.
+ *      The return value is the X identifer for the desired cursor,
+ *      unless it couldn't be created properly.  In this case, None is
+ *      returned and an error message is left in the interp's result.  The
+ *      caller should never modify the cursor that is returned, and
+ *      should eventually call Tk_FreeCursor when the cursor is no
+ *      longer needed.
  *
  * Side effects:
- *	The cursor is added to an internal database with a reference count.
- *	For each call to this procedure, there should eventually be a call
- *	to Tk_FreeCursor, so that the database can be cleaned up when cursors
- *	aren't needed anymore.
+ *      The cursor is added to an internal database with a reference count.
+ *      For each call to this procedure, there should eventually be a call
+ *      to Tk_FreeCursor, so that the database can be cleaned up when cursors
+ *      aren't needed anymore.
  *
  *----------------------------------------------------------------------
  */
@@ -316,14 +316,14 @@ GetCursor(interp, tkwin, string)
 Tk_Cursor
 Tk_GetCursorFromData(interp, tkwin, source, mask, width, height,
 	xHot, yHot, fg, bg)
-    Tcl_Interp *interp;		/* Interpreter to use for error reporting. */
-    Tk_Window tkwin;		/* Window in which cursor will be used. */
-    CONST char *source;		/* Bitmap data for cursor shape. */
-    CONST char *mask;		/* Bitmap data for cursor mask. */
-    int width, height;		/* Dimensions of cursor. */
-    int xHot, yHot;		/* Location of hot-spot in cursor. */
-    Tk_Uid fg;			/* Foreground color for cursor. */
-    Tk_Uid bg;			/* Background color for cursor. */
+    Tcl_Interp *interp;         /* Interpreter to use for error reporting. */
+    Tk_Window tkwin;            /* Window in which cursor will be used. */
+    CONST char *source;         /* Bitmap data for cursor shape. */
+    CONST char *mask;           /* Bitmap data for cursor mask. */
+    int width, height;          /* Dimensions of cursor. */
+    int xHot, yHot;             /* Location of hot-spot in cursor. */
+    Tk_Uid fg;                  /* Foreground color for cursor. */
+    Tk_Uid bg;                  /* Background color for cursor. */
 {
     DataKey dataKey;
     Tcl_HashEntry *dataHashPtr;
@@ -347,7 +347,7 @@ Tk_GetCursorFromData(interp, tkwin, source, mask, width, height,
     dataKey.bg = bg;
     dataKey.display = Tk_Display(tkwin);
     dataHashPtr = Tcl_CreateHashEntry(&dispPtr->cursorDataTable,
-            (char *) &dataKey, &new);
+	    (char *) &dataKey, &new);
     if (!new) {
 	cursorPtr = (TkCursor *) Tcl_GetHashValue(dataHashPtr);
 	cursorPtr->resourceRefCount++;
@@ -382,7 +382,7 @@ Tk_GetCursorFromData(interp, tkwin, source, mask, width, height,
     cursorPtr->hashPtr = dataHashPtr;
     cursorPtr->objRefCount = 0;
     cursorPtr->idHashPtr = Tcl_CreateHashEntry(&dispPtr->cursorIdTable,
-            (char *) cursorPtr->cursor, &new);
+	    (char *) cursorPtr->cursor, &new);
     cursorPtr->nextPtr = NULL;
 
     if (!new) {
@@ -402,26 +402,26 @@ Tk_GetCursorFromData(interp, tkwin, source, mask, width, height,
  *
  * Tk_NameOfCursor --
  *
- *	Given a cursor, return a textual string identifying it.
+ *      Given a cursor, return a textual string identifying it.
  *
  * Results:
- *	If cursor was created by Tk_GetCursor, then the return
- *	value is the "string" that was used to create it.
- *	Otherwise the return value is a string giving the X
- *	identifier for the cursor.  The storage for the returned
- *	string is only guaranteed to persist up until the next
- *	call to this procedure.
+ *      If cursor was created by Tk_GetCursor, then the return
+ *      value is the "string" that was used to create it.
+ *      Otherwise the return value is a string giving the X
+ *      identifier for the cursor.  The storage for the returned
+ *      string is only guaranteed to persist up until the next
+ *      call to this procedure.
  *
  * Side effects:
- *	None.
+ *      None.
  *
  *--------------------------------------------------------------
  */
 
 CONST char *
 Tk_NameOfCursor(display, cursor)
-    Display *display;		/* Display for which cursor was allocated. */
-    Tk_Cursor cursor;		/* Identifier for cursor whose name is
+    Display *display;           /* Display for which cursor was allocated. */
+    Tk_Cursor cursor;           /* Identifier for cursor whose name is
 				 * wanted. */
 {
     Tcl_HashEntry *idHashPtr;
@@ -433,7 +433,7 @@ Tk_NameOfCursor(display, cursor)
     if (!dispPtr->cursorInit) {
 	printid:
 	sprintf(dispPtr->cursorString, "cursor id 0x%x",
-                (unsigned int) cursor);
+		(unsigned int) cursor);
 	return dispPtr->cursorString;
     }
     idHashPtr = Tcl_FindHashEntry(&dispPtr->cursorIdTable, (char *) cursor);
@@ -452,23 +452,23 @@ Tk_NameOfCursor(display, cursor)
  *
  * FreeCursor --
  *
- *	This procedure is invoked by both Tk_FreeCursor and
- *	Tk_FreeCursorFromObj; it does all the real work of deallocating
- *	a cursor.
+ *      This procedure is invoked by both Tk_FreeCursor and
+ *      Tk_FreeCursorFromObj; it does all the real work of deallocating
+ *      a cursor.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The reference count associated with cursor is decremented, and
- *	it is officially deallocated if no-one is using it anymore.
+ *      The reference count associated with cursor is decremented, and
+ *      it is officially deallocated if no-one is using it anymore.
  *
  *----------------------------------------------------------------------
  */
 
 static void
 FreeCursor(cursorPtr)
-    TkCursor *cursorPtr;	/* Cursor to be released. */
+    TkCursor *cursorPtr;        /* Cursor to be released. */
 {
     TkCursor *prevPtr;
 
@@ -502,23 +502,23 @@ FreeCursor(cursorPtr)
  *
  * Tk_FreeCursor --
  *
- *	This procedure is called to release a cursor allocated by
- *	Tk_GetCursor or TkGetCursorFromData.
+ *      This procedure is called to release a cursor allocated by
+ *      Tk_GetCursor or TkGetCursorFromData.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The reference count associated with cursor is decremented, and
- *	it is officially deallocated if no-one is using it anymore.
+ *      The reference count associated with cursor is decremented, and
+ *      it is officially deallocated if no-one is using it anymore.
  *
  *----------------------------------------------------------------------
  */
 
 void
 Tk_FreeCursor(display, cursor)
-    Display *display;		/* Display for which cursor was allocated. */
-    Tk_Cursor cursor;		/* Identifier for cursor to be released. */
+    Display *display;           /* Display for which cursor was allocated. */
+    Tk_Cursor cursor;           /* Identifier for cursor to be released. */
 {
     Tcl_HashEntry *idHashPtr;
     TkDisplay *dispPtr = TkGetDisplay(display);
@@ -539,27 +539,27 @@ Tk_FreeCursor(display, cursor)
  *
  * Tk_FreeCursorFromObj --
  *
- *	This procedure is called to release a cursor allocated by
- *	Tk_AllocCursorFromObj. It does not throw away the Tcl_Obj *;
- *	it only gets rid of the hash table entry for this cursor
- *	and clears the cached value that is normally stored in the object.
+ *      This procedure is called to release a cursor allocated by
+ *      Tk_AllocCursorFromObj. It does not throw away the Tcl_Obj *;
+ *      it only gets rid of the hash table entry for this cursor
+ *      and clears the cached value that is normally stored in the object.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The reference count associated with the cursor represented by
- *	objPtr is decremented, and the cursor is released to X if there are
- *	no remaining uses for it.
+ *      The reference count associated with the cursor represented by
+ *      objPtr is decremented, and the cursor is released to X if there are
+ *      no remaining uses for it.
  *
  *----------------------------------------------------------------------
  */
 
 void
 Tk_FreeCursorFromObj(tkwin, objPtr)
-    Tk_Window tkwin;		/* The window this cursor lives in. Needed
+    Tk_Window tkwin;            /* The window this cursor lives in. Needed
 				 * for the display value. */
-    Tcl_Obj *objPtr;		/* The Tcl_Obj * to be freed. */
+    Tcl_Obj *objPtr;            /* The Tcl_Obj * to be freed. */
 {
     FreeCursor(GetCursorFromObj(tkwin, objPtr));
     FreeCursorObjProc(objPtr);
@@ -570,24 +570,24 @@ Tk_FreeCursorFromObj(tkwin, objPtr)
  *
  * FreeCursorFromObjProc --
  *
- *	This proc is called to release an object reference to a cursor.
- *	Called when the object's internal rep is released or when
- *	the cached tkColPtr needs to be changed.
+ *      This proc is called to release an object reference to a cursor.
+ *      Called when the object's internal rep is released or when
+ *      the cached tkColPtr needs to be changed.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The object reference count is decremented. When both it
- *	and the hash ref count go to zero, the color's resources
- *	are released.
+ *      The object reference count is decremented. When both it
+ *      and the hash ref count go to zero, the color's resources
+ *      are released.
  *
  *---------------------------------------------------------------------------
  */
 
 static void
 FreeCursorObjProc(objPtr)
-    Tcl_Obj *objPtr;		/* The object we are releasing. */
+    Tcl_Obj *objPtr;            /* The object we are releasing. */
 {
     TkCursor *cursorPtr = (TkCursor *) objPtr->internalRep.twoPtrValue.ptr1;
 
@@ -606,23 +606,23 @@ FreeCursorObjProc(objPtr)
  *
  * DupCursorObjProc --
  *
- *	When a cached cursor object is duplicated, this is called to
- *	update the internal reps.
+ *      When a cached cursor object is duplicated, this is called to
+ *      update the internal reps.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The color's objRefCount is incremented and the internal rep
- *	of the copy is set to point to it.
+ *      The color's objRefCount is incremented and the internal rep
+ *      of the copy is set to point to it.
  *
  *---------------------------------------------------------------------------
  */
 
 static void
 DupCursorObjProc(srcObjPtr, dupObjPtr)
-    Tcl_Obj *srcObjPtr;		/* The object we are copying from. */
-    Tcl_Obj *dupObjPtr;		/* The object we are copying to. */
+    Tcl_Obj *srcObjPtr;         /* The object we are copying from. */
+    Tcl_Obj *dupObjPtr;         /* The object we are copying to. */
 {
     TkCursor *cursorPtr = (TkCursor *) srcObjPtr->internalRep.twoPtrValue.ptr1;
 
@@ -639,17 +639,17 @@ DupCursorObjProc(srcObjPtr, dupObjPtr)
  *
  * Tk_GetCursorFromObj --
  *
- *	Returns the cursor referred to buy a Tcl object. The cursor must
- *	already have been allocated via a call to Tk_AllocCursorFromObj or
- *	Tk_GetCursor.
+ *      Returns the cursor referred to buy a Tcl object. The cursor must
+ *      already have been allocated via a call to Tk_AllocCursorFromObj or
+ *      Tk_GetCursor.
  *
  * Results:
- *	Returns the Tk_Cursor that matches the tkwin and the string rep
- *	of the name of the cursor given in objPtr.
+ *      Returns the Tk_Cursor that matches the tkwin and the string rep
+ *      of the name of the cursor given in objPtr.
  *
  * Side effects:
- *	If the object is not already a cursor, the conversion will free
- *	any old internal representation.
+ *      If the object is not already a cursor, the conversion will free
+ *      any old internal representation.
  *
  *----------------------------------------------------------------------
  */
@@ -657,7 +657,7 @@ DupCursorObjProc(srcObjPtr, dupObjPtr)
 Tk_Cursor
 Tk_GetCursorFromObj(tkwin, objPtr)
     Tk_Window tkwin;
-    Tcl_Obj *objPtr;		/* The object from which to get pixels. */
+    Tcl_Obj *objPtr;            /* The object from which to get pixels. */
 {
     TkCursor *cursorPtr = GetCursorFromObj(tkwin, objPtr);
     /* GetCursorFromObj should never return NULL */
@@ -669,25 +669,25 @@ Tk_GetCursorFromObj(tkwin, objPtr)
  *
  * GetCursorFromObj --
  *
- *	Returns the cursor referred to by a Tcl object.  The cursor must
- *	already have been allocated via a call to Tk_AllocCursorFromObj
- *	or Tk_GetCursor.
+ *      Returns the cursor referred to by a Tcl object.  The cursor must
+ *      already have been allocated via a call to Tk_AllocCursorFromObj
+ *      or Tk_GetCursor.
  *
  * Results:
- *	Returns the TkCursor * that matches the tkwin and the string rep
- *	of the name of the cursor given in objPtr.
+ *      Returns the TkCursor * that matches the tkwin and the string rep
+ *      of the name of the cursor given in objPtr.
  *
  * Side effects:
- *	If the object is not already a cursor, the conversion will free
- *	any old internal representation.
+ *      If the object is not already a cursor, the conversion will free
+ *      any old internal representation.
  *
  *----------------------------------------------------------------------
  */
 
 static TkCursor *
 GetCursorFromObj(tkwin, objPtr)
-    Tk_Window tkwin;		/* Window in which the cursor will be used. */
-    Tcl_Obj *objPtr;		/* The object that describes the desired
+    Tk_Window tkwin;            /* Window in which the cursor will be used. */
+    Tcl_Obj *objPtr;            /* The object that describes the desired
 				 * cursor. */
 {
     TkCursor *cursorPtr;
@@ -742,22 +742,22 @@ GetCursorFromObj(tkwin, objPtr)
  *
  * InitCursorObj --
  *
- *	Bookeeping procedure to change an objPtr to a cursor type.
+ *      Bookeeping procedure to change an objPtr to a cursor type.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	The old internal rep of the object is freed. The internal
- *	rep is cleared. The final form of the object is set
- *	by either Tk_AllocCursorFromObj or GetCursorFromObj.
+ *      The old internal rep of the object is freed. The internal
+ *      rep is cleared. The final form of the object is set
+ *      by either Tk_AllocCursorFromObj or GetCursorFromObj.
  *
  *----------------------------------------------------------------------
  */
 
 static void
 InitCursorObj(objPtr)
-    Tcl_Obj *objPtr;		/* The object to convert. */
+    Tcl_Obj *objPtr;            /* The object to convert. */
 {
     Tcl_ObjType *typePtr;
 
@@ -779,13 +779,13 @@ InitCursorObj(objPtr)
  *
  * CursorInit --
  *
- *	Initialize the structures used for cursor management.
+ *      Initialize the structures used for cursor management.
  *
  * Results:
- *	None.
+ *      None.
  *
  * Side effects:
- *	Read the code.
+ *      Read the code.
  *
  *----------------------------------------------------------------------
  */
@@ -823,25 +823,25 @@ CursorInit(dispPtr)
  *
  * TkDebugCursor --
  *
- *	This procedure returns debugging information about a cursor.
+ *      This procedure returns debugging information about a cursor.
  *
  * Results:
- *	The return value is a list with one sublist for each TkCursor
- *	corresponding to "name".  Each sublist has two elements that
- *	contain the resourceRefCount and objRefCount fields from the
- *	TkCursor structure.
+ *      The return value is a list with one sublist for each TkCursor
+ *      corresponding to "name".  Each sublist has two elements that
+ *      contain the resourceRefCount and objRefCount fields from the
+ *      TkCursor structure.
  *
  * Side effects:
- *	None.
+ *      None.
  *
  *----------------------------------------------------------------------
  */
 
 Tcl_Obj *
 TkDebugCursor(tkwin, name)
-    Tk_Window tkwin;		/* The window in which the cursor will be
+    Tk_Window tkwin;            /* The window in which the cursor will be
 				 * used (not currently used). */
-    char *name;			/* Name of the desired color. */
+    char *name;                 /* Name of the desired color. */
 {
     TkCursor *cursorPtr;
     Tcl_HashEntry *hashPtr;
