@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tkMenubutton.c,v 1.12 2002/08/05 04:30:40 dgp Exp $
+ * RCS: @(#) $Id: tkMenubutton.c,v 1.12.2.1 2003/11/17 23:29:36 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -136,8 +136,8 @@ static Tk_OptionSpec optionSpecs[] = {
     {TK_OPTION_STRING, "-text", "text", "Text",
 	DEF_MENUBUTTON_TEXT, -1, Tk_Offset(TkMenuButton, text), 0, 0, 0},
     {TK_OPTION_OBJ, "-textvariable", "textVariable", "Variable",
-	DEF_MENUBUTTON_TEXT_VARIABLE, -1,
-        Tk_Offset(TkMenuButton, textVarName), TK_OPTION_NULL_OK, 0, 0},
+	DEF_MENUBUTTON_TEXT_VARIABLE,
+        -1, Tk_Offset(TkMenuButton, textVarName), TK_OPTION_NULL_OK, 0, 0},
     {TK_OPTION_INT, "-underline", "underline", "Underline",
 	DEF_MENUBUTTON_UNDERLINE, -1, Tk_Offset(TkMenuButton, underline),
          0, 0, 0},
@@ -278,6 +278,7 @@ Tk_MenubuttonObjCmd(clientData, interp, objc, objv)
     mbPtr->activeTextGC = None;
     mbPtr->gray = None;
     mbPtr->disabledGC = None;
+    mbPtr->stippleGC = None;
     mbPtr->leftBearing = 0;
     mbPtr->rightBearing = 0;
     mbPtr->widthString = NULL;
@@ -453,14 +454,16 @@ DestroyMenuButton(memPtr)
     if (mbPtr->disabledGC != None) {
 	Tk_FreeGC(mbPtr->display, mbPtr->disabledGC);
     }
+    if (mbPtr->stippleGC != None) {
+	Tk_FreeGC(mbPtr->display, mbPtr->stippleGC);
+    }
     if (mbPtr->gray != None) {
 	Tk_FreeBitmap(mbPtr->display, mbPtr->gray);
     }
     if (mbPtr->textLayout != NULL) {
         Tk_FreeTextLayout(mbPtr->textLayout);
     }
-    Tk_FreeConfigOptions((char *) mbPtr, mbPtr->optionTable,
-	    mbPtr->tkwin);
+    Tk_FreeConfigOptions((char *) mbPtr, mbPtr->optionTable, mbPtr->tkwin);
     mbPtr->tkwin = NULL;
     Tcl_EventuallyFree((ClientData) mbPtr, TCL_DYNAMIC);
 }
@@ -706,7 +709,6 @@ TkMenuButtonWorldChanged(instanceData)
     }
     mbPtr->normalTextGC = gc;
 
-    gcValues.font = Tk_FontId(mbPtr->tkfont);
     gcValues.foreground = mbPtr->activeFg->pixel;
     gcValues.background = Tk_3DBorderColor(mbPtr->activeBorder)->pixel;
     mask = GCForeground | GCBackground | GCFont;
@@ -716,23 +718,36 @@ TkMenuButtonWorldChanged(instanceData)
     }
     mbPtr->activeTextGC = gc;
 
-    gcValues.font = Tk_FontId(mbPtr->tkfont);
     gcValues.background = Tk_3DBorderColor(mbPtr->normalBorder)->pixel;
-    if ((mbPtr->disabledFg != NULL) && (mbPtr->imageString == NULL)) {
-	gcValues.foreground = mbPtr->disabledFg->pixel;
-	mask = GCForeground | GCBackground | GCFont;
-    } else {
+
+    /*
+     * Create the GC that can be used for stippling
+     */
+
+    if (mbPtr->stippleGC == None) {
 	gcValues.foreground = gcValues.background;
 	mask = GCForeground;
 	if (mbPtr->gray == None) {
-	    mbPtr->gray = Tk_GetBitmap(NULL, mbPtr->tkwin,
-		    Tk_GetUid("gray50"));
+	    mbPtr->gray = Tk_GetBitmap(NULL, mbPtr->tkwin, "gray50");
 	}
 	if (mbPtr->gray != None) {
 	    gcValues.fill_style = FillStippled;
 	    gcValues.stipple = mbPtr->gray;
 	    mask |= GCFillStyle | GCStipple;
 	}
+	mbPtr->stippleGC = Tk_GetGC(mbPtr->tkwin, mask, &gcValues);
+    }
+
+    /*
+     * Allocate the disabled graphics context, for drawing text in
+     * its disabled state.
+     */
+
+    mask = GCForeground | GCBackground | GCFont;
+    if (mbPtr->disabledFg != NULL) {
+	gcValues.foreground = mbPtr->disabledFg->pixel;
+    } else {
+	gcValues.foreground = gcValues.background;
     }
     gc = Tk_GetGC(mbPtr->tkwin, mask, &gcValues);
     if (mbPtr->disabledGC != None) {
