@@ -1,4 +1,4 @@
-/* 
+/*
  * tclAsync.c --
  *
  *	This file provides low-level support needed to invoke signal
@@ -12,12 +12,15 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclAsync.c,v 1.2 1998/09/14 18:39:57 stanton Exp $
+ * RCS: @(#) $Id: tclAsync.c,v 1.6 2001/08/30 07:50:18 davygrvy Exp $
  */
-
+#ifdef TCL_EVENT_IMPLEMENT
 #include "tkPort.h"
 #include "Lang.h"
 
+/* Forward declaration */
+struct ThreadSpecificData;
+
 /*
  * One of the following structures exists for each asynchronous
  * handler:
@@ -33,33 +36,75 @@ typedef struct AsyncHandler {
 					 * is invoked. */
     ClientData clientData;		/* Value to pass to handler when it
 					 * is invoked. */
+    struct ThreadSpecificData *originTsd;
+					/* Used in Tcl_AsyncMark to modify thread-
+					 * specific data from outside the thread
+					 * it is associated to. */
+    Tcl_ThreadId originThrdId;		/* Origin thread where this token was
+					 * created and where it will be
+					 * yielded. */
 } AsyncHandler;
 
-/*
- * The variables below maintain a list of all existing handlers.
- */
 
-static AsyncHandler *firstHandler;	/* First handler defined for process,
-					 * or NULL if none. */
-static AsyncHandler *lastHandler;	/* Last handler or NULL. */
+typedef struct ThreadSpecificData {
+    /*
+     * The variables below maintain a list of all existing handlers
+     * specific to the calling thread.
+     */
+    AsyncHandler *firstHandler;	    /* First handler defined for process,
+				     * or NULL if none. */
+    AsyncHandler *lastHandler;	    /* Last handler or NULL. */
+
+    /*
+     * The variable below is set to 1 whenever a handler becomes ready and
+     * it is cleared to zero whenever Tcl_AsyncInvoke is called.  It can be
+     * checked elsewhere in the application by calling Tcl_AsyncReady to see
+     * if Tcl_AsyncInvoke should be invoked.
+     */
+
+    int asyncReady;
+
+    /*
+     * The variable below indicates whether Tcl_AsyncInvoke is currently
+     * working.  If so then we won't set asyncReady again until
+     * Tcl_AsyncInvoke returns.
+     */
+
+    int asyncActive;
+
+    Tcl_Mutex asyncMutex;   /* Thread-specific AsyncHandler linked-list lock */
+
+} ThreadSpecificData;
+static Tcl_ThreadDataKey dataKey;
+
 
 /*
- * The variable below is set to 1 whenever a handler becomes ready and
- * it is cleared to zero whenever Tcl_AsyncInvoke is called.  It can be
- * checked elsewhere in the application by calling Tcl_AsyncReady to see
- * if Tcl_AsyncInvoke should be invoked.
+ *----------------------------------------------------------------------
+ *
+ * TclFinalizeAsync --
+ *
+ *	Finalizes the mutex in the thread local data structure for the
+ *	async subsystem.
+ *
+ * Results:
+ *	None.
+ *
+ * Side effects:
+ *	Forgets knowledge of the mutex should it have been created.
+ *
+ *----------------------------------------------------------------------
  */
 
-static int asyncReady = 0;
+void
+TclFinalizeAsync()
+{
+    ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
 
-/*
- * The variable below indicates whether Tcl_AsyncInvoke is currently
- * working.  If so then we won't set asyncReady again until
- * Tcl_AsyncInvoke returns.
- */
+    if (tsdPtr->asyncMutex != NULL) {
+	Tcl_MutexFinalize(&tsdPtr->asyncMutex);
+    }
+}
 
-static int asyncActive = 0;
-
 /*
  *----------------------------------------------------------------------
  *
@@ -86,21 +131,27 @@ Tcl_AsyncCreate(proc, clientData)
     ClientData clientData;		/* Argument to pass to handler. */
 {
     AsyncHandler *asyncPtr;
+    ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
 
     asyncPtr = (AsyncHandler *) ckalloc(sizeof(AsyncHandler));
     asyncPtr->ready = 0;
     asyncPtr->nextPtr = NULL;
     asyncPtr->proc = proc;
     asyncPtr->clientData = clientData;
-    if (firstHandler == NULL) {
-	firstHandler = asyncPtr;
+    asyncPtr->originTsd = tsdPtr;
+    asyncPtr->originThrdId = Tcl_GetCurrentThread();
+
+    Tcl_MutexLock(&tsdPtr->asyncMutex);
+    if (tsdPtr->firstHandler == NULL) {
+	tsdPtr->firstHandler = asyncPtr;
     } else {
-	lastHandler->nextPtr = asyncPtr;
+	tsdPtr->lastHandler->nextPtr = asyncPtr;
     }
-    lastHandler = asyncPtr;
+    tsdPtr->lastHandler = asyncPtr;
+    Tcl_MutexUnlock(&tsdPtr->asyncMutex);
     return (Tcl_AsyncHandler) asyncPtr;
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -124,12 +175,17 @@ void
 Tcl_AsyncMark(async)
     Tcl_AsyncHandler async;		/* Token for handler. */
 {
-    ((AsyncHandler *) async)->ready = 1;
-    if (!asyncActive) {
-	asyncReady = 1;
+    AsyncHandler *token = (AsyncHandler *) async;
+
+    Tcl_MutexLock(&token->originTsd->asyncMutex);
+    token->ready = 1;
+    if (!token->originTsd->asyncActive) {
+	token->originTsd->asyncReady = 1;
+	Tcl_ThreadAlert(token->originThrdId);
     }
+    Tcl_MutexUnlock(&token->originTsd->asyncMutex);
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -160,12 +216,16 @@ Tcl_AsyncInvoke(interp, code)
 					 * just completed. */
 {
     AsyncHandler *asyncPtr;
+    ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
 
-    if (asyncReady == 0) {
+    Tcl_MutexLock(&tsdPtr->asyncMutex);
+
+    if (tsdPtr->asyncReady == 0) {
+	Tcl_MutexUnlock(&tsdPtr->asyncMutex);
 	return code;
     }
-    asyncReady = 0;
-    asyncActive = 1;
+    tsdPtr->asyncReady = 0;
+    tsdPtr->asyncActive = 1;
     if (interp == NULL) {
 	code = 0;
     }
@@ -182,7 +242,7 @@ Tcl_AsyncInvoke(interp, code)
      */
 
     while (1) {
-	for (asyncPtr = firstHandler; asyncPtr != NULL;
+	for (asyncPtr = tsdPtr->firstHandler; asyncPtr != NULL;
 		asyncPtr = asyncPtr->nextPtr) {
 	    if (asyncPtr->ready) {
 		break;
@@ -192,12 +252,15 @@ Tcl_AsyncInvoke(interp, code)
 	    break;
 	}
 	asyncPtr->ready = 0;
+	Tcl_MutexUnlock(&tsdPtr->asyncMutex);
 	code = (*asyncPtr->proc)(asyncPtr->clientData, interp, code);
+	Tcl_MutexLock(&tsdPtr->asyncMutex);
     }
-    asyncActive = 0;
+    tsdPtr->asyncActive = 0;
+    Tcl_MutexUnlock(&tsdPtr->asyncMutex);
     return code;
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -219,27 +282,30 @@ void
 Tcl_AsyncDelete(async)
     Tcl_AsyncHandler async;		/* Token for handler to delete. */
 {
+    ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
     AsyncHandler *asyncPtr = (AsyncHandler *) async;
     AsyncHandler *prevPtr;
 
-    if (firstHandler == asyncPtr) {
-	firstHandler = asyncPtr->nextPtr;
-	if (firstHandler == NULL) {
-	    lastHandler = NULL;
+    Tcl_MutexLock(&tsdPtr->asyncMutex);
+    if (tsdPtr->firstHandler == asyncPtr) {
+	tsdPtr->firstHandler = asyncPtr->nextPtr;
+	if (tsdPtr->firstHandler == NULL) {
+	    tsdPtr->lastHandler = NULL;
 	}
     } else {
-	prevPtr = firstHandler;
+	prevPtr = tsdPtr->firstHandler;
 	while (prevPtr->nextPtr != asyncPtr) {
 	    prevPtr = prevPtr->nextPtr;
 	}
 	prevPtr->nextPtr = asyncPtr->nextPtr;
-	if (lastHandler == asyncPtr) {
-	    lastHandler = prevPtr;
+	if (tsdPtr->lastHandler == asyncPtr) {
+	    tsdPtr->lastHandler = prevPtr;
 	}
     }
+    Tcl_MutexUnlock(&tsdPtr->asyncMutex);
     ckfree((char *) asyncPtr);
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -247,7 +313,7 @@ Tcl_AsyncDelete(async)
  *
  *	This procedure can be used to tell whether Tcl_AsyncInvoke
  *	needs to be called.  This procedure is the external interface
- *	for checking the internal asyncReady variable.
+ *	for checking the thread-specific asyncReady variable.
  *
  * Results:
  * 	The return value is 1 whenever a handler is ready and is 0
@@ -262,5 +328,8 @@ Tcl_AsyncDelete(async)
 int
 Tcl_AsyncReady()
 {
-    return asyncReady;
+    ThreadSpecificData *tsdPtr = TCL_TSD_INIT(&dataKey);
+    return tsdPtr->asyncReady;
 }
+
+#endif
