@@ -1,4 +1,4 @@
-/* 
+/*
  * tclPreserve.c --
  *
  *	This file contains a collection of procedures that are used
@@ -12,7 +12,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclPreserve.c,v 1.3 1999/04/16 00:46:52 stanton Exp $
+ * RCS: @(#) $Id: tclPreserve.c,v 1.3.34.1 2003/07/16 21:25:07 hobbs Exp $
  */
 
 #include "tkPort.h"
@@ -73,7 +73,7 @@ typedef struct HandleStruct {
 
 static void	PreserveExitProc _ANSI_ARGS_((ClientData clientData));
 
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -104,7 +104,7 @@ PreserveExitProc(clientData)
     }
     Tcl_MutexUnlock(&preserveMutex);
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -182,7 +182,7 @@ Tcl_Preserve(clientData)
     inUse += 1;
     Tcl_MutexUnlock(&preserveMutex);
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -234,8 +234,7 @@ Tcl_Release(clientData)
 		refArray[i] = refArray[inUse];
 	    }
 	    if (mustFree) {
-		if ((freeProc == TCL_DYNAMIC) ||
-                        (freeProc == (Tcl_FreeProc *) free)) {
+		if (freeProc == TCL_DYNAMIC) {
 		    ckfree((char *) clientData);
 		} else {
 		    Tcl_MutexUnlock(&preserveMutex);
@@ -255,7 +254,7 @@ Tcl_Release(clientData)
 
     panic("Tcl_Release couldn't find reference for 0x%x", clientData);
 }
-
+
 /*
  *----------------------------------------------------------------------
  *
@@ -307,21 +306,20 @@ Tcl_EventuallyFree(clientData, freeProc)
      * No reference for this block.  Free it now.
      */
 
-    if ((freeProc == TCL_DYNAMIC)
-	    || (freeProc == (Tcl_FreeProc *) free)) {
+    if (freeProc == TCL_DYNAMIC) {
 	ckfree((char *) clientData);
     } else {
 	(*freeProc)((char *)clientData);
     }
 }
-
+
 /*
  *---------------------------------------------------------------------------
  *
  * TclHandleCreate --
  *
  *	Allocate a handle that contains enough information to determine
- *	if an arbitrary malloc'd block has been deleted.  This is 
+ *	if an arbitrary malloc'd block has been deleted.  This is
  *	used to avoid the more time-expensive algorithm of Tcl_Preserve().
  *
  * Results:
@@ -357,7 +355,7 @@ TclHandleCreate(ptr)
     handlePtr->refCount = 0;
     return (TclHandle) handlePtr;
 }
-
+
 /*
  *---------------------------------------------------------------------------
  *
@@ -402,14 +400,14 @@ TclHandleFree(handle)
 	ckfree((char *) handlePtr);
     }
 }
-
+
 /*
  *---------------------------------------------------------------------------
  *
  * TclHandlePreserve --
  *
  *	Declare an interest in the arbitrary malloc'd block associated
- *	with the handle.  
+ *	with the handle.
  *
  * Results:
  *	The return value is the handle argument, with its ref count
@@ -445,7 +443,7 @@ TclHandlePreserve(handle)
 
     return handle;
 }
-
+
 /*
  *---------------------------------------------------------------------------
  *
@@ -464,7 +462,7 @@ TclHandlePreserve(handle)
  *
  *---------------------------------------------------------------------------
  */
- 
+
 void
 TclHandleRelease(handle)
     TclHandle handle;		/* Unregister interest in the block of
@@ -488,4 +486,4 @@ TclHandleRelease(handle)
 	ckfree((char *) handlePtr);
     }
 }
-    
+
