@@ -7,7 +7,7 @@
  * Copyright (c) 1999 by Scriptics Corporation.
  * All rights reserved.
  *
- * RCS: @(#) $Id: tclUnixInit.c,v 1.33 2002/09/02 19:27:42 hobbs Exp $
+ * RCS: @(#) $Id: tclUnixInit.c,v 1.34.2.2 2003/11/10 20:32:34 dgp Exp $
  */
 
 #if defined(HAVE_CFBUNDLE)
@@ -342,7 +342,25 @@ CONST char *path;		/* Path to the executable in native
       */
 
     if (path != NULL) {
-	Tcl_SplitPath(path, &pathc, &pathv);
+	int i, origc;
+	CONST char **origv;
+
+	Tcl_SplitPath(path, &origc, &origv);
+	pathc = 0;
+	pathv = (CONST char **) ckalloc((unsigned int)(origc * sizeof(char *)));
+	for (i=0; i< origc; i++) {
+	    if (origv[i][0] == '.') {
+		if (strcmp(origv[i], ".") == 0) {
+		    /* do nothing */
+		} else if (strcmp(origv[i], "..") == 0) {
+		    pathc--;
+		} else {
+		    pathv[pathc++] = origv[i];
+		}
+	    } else {
+		pathv[pathc++] = origv[i];
+	    }
+	}
 	if (pathc > 2) {
 	    str = pathv[pathc - 2];
 	    pathv[pathc - 2] = installLib;
@@ -397,6 +415,7 @@ CONST char *path;		/* Path to the executable in native
 	    Tcl_ListObjAppendElement(NULL, pathPtr, objPtr);
 	    Tcl_DStringFree(&ds);
 	}
+	ckfree((char *) origv);
 	ckfree((char *) pathv);
     }
 
@@ -408,9 +427,9 @@ CONST char *path;		/* Path to the executable in native
 
     {
 #ifdef HAVE_CFBUNDLE
-    char tclLibPath[1024];
+    char tclLibPath[MAXPATHLEN + 1];
 
-    if (Tcl_MacOSXGetLibraryPath(NULL, 1024, tclLibPath) == TCL_OK) {
+    if (Tcl_MacOSXGetLibraryPath(NULL, MAXPATHLEN, tclLibPath) == TCL_OK) {
         str = tclLibPath;
     } else
 #endif /* HAVE_CFBUNDLE */
@@ -704,15 +723,60 @@ TclpSetVariables(interp)
     Tcl_DString ds;
 
 #ifdef HAVE_CFBUNDLE
-    char tclLibPath[1024];
+    char tclLibPath[MAXPATHLEN + 1];
+
+    if (Tcl_MacOSXGetLibraryPath(interp, MAXPATHLEN, tclLibPath) == TCL_OK) {
+        CONST char *str;
+        Tcl_DString ds;
+        CFBundleRef bundleRef;
 
-    if (Tcl_MacOSXGetLibraryPath(interp, 1024, tclLibPath) == TCL_OK) {
         Tcl_SetVar(interp, "tclDefaultLibrary", tclLibPath,
                 TCL_GLOBAL_ONLY);
         Tcl_SetVar(interp, "tcl_pkgPath", tclLibPath,
                 TCL_GLOBAL_ONLY);
         Tcl_SetVar(interp, "tcl_pkgPath", " ",
                 TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+        str = TclGetEnv("DYLD_FRAMEWORK_PATH", &ds);
+        if ((str != NULL) && (str[0] != '\0')) {
+            char *p = Tcl_DStringValue(&ds);
+            /* convert DYLD_FRAMEWORK_PATH from colon to space separated */
+            do {
+                if(*p == ':') *p = ' ';
+            } while (*p++);
+            Tcl_SetVar(interp, "tcl_pkgPath", Tcl_DStringValue(&ds),
+                    TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+            Tcl_SetVar(interp, "tcl_pkgPath", " ",
+                    TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+            Tcl_DStringFree(&ds);
+        }
+        if ((bundleRef = CFBundleGetMainBundle())) {
+            CFURLRef frameworksURL;
+            Tcl_StatBuf statBuf;
+            if((frameworksURL = CFBundleCopyPrivateFrameworksURL(bundleRef))) {
+                if(CFURLGetFileSystemRepresentation(frameworksURL, TRUE,
+                            tclLibPath, MAXPATHLEN) &&
+                        ! TclOSstat(tclLibPath, &statBuf) &&
+                        S_ISDIR(statBuf.st_mode)) {
+                    Tcl_SetVar(interp, "tcl_pkgPath", tclLibPath,
+                            TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+                    Tcl_SetVar(interp, "tcl_pkgPath", " ",
+                            TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+                }
+                CFRelease(frameworksURL);
+            }
+            if((frameworksURL = CFBundleCopySharedFrameworksURL(bundleRef))) {
+                if(CFURLGetFileSystemRepresentation(frameworksURL, TRUE,
+                            tclLibPath, MAXPATHLEN) &&
+                        ! TclOSstat(tclLibPath, &statBuf) &&
+                        S_ISDIR(statBuf.st_mode)) {
+                    Tcl_SetVar(interp, "tcl_pkgPath", tclLibPath,
+                            TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+                    Tcl_SetVar(interp, "tcl_pkgPath", " ",
+                            TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
+                }
+                CFRelease(frameworksURL);
+            }
+        }
         Tcl_SetVar(interp, "tcl_pkgPath", pkgPath,
                 TCL_GLOBAL_ONLY | TCL_APPEND_VALUE);
     } else
@@ -986,7 +1050,7 @@ TclpCheckStackSpace()
  *	TCL_OK if we have found the tcl library; TCL_ERROR otherwise.
  *
  * Side effects:
- *	Same as for Tcl_MacOSXOpenBundleResources.
+ *	Same as for Tcl_MacOSXOpenVersionedBundleResources.
  *
  *----------------------------------------------------------------------
  */
@@ -994,8 +1058,8 @@ static int Tcl_MacOSXGetLibraryPath(Tcl_Interp *interp, int maxPathLen, char *tc
 {
     int foundInFramework = TCL_ERROR;
     if (strcmp(defaultLibraryDir, "@TCL_IN_FRAMEWORK@") == 0) {
-	foundInFramework = Tcl_MacOSXOpenBundleResources(interp,
-	    "com.tcltk.tcllibrary", 0, maxPathLen, tclLibPath);
+	foundInFramework = Tcl_MacOSXOpenVersionedBundleResources(interp,
+	    "com.tcltk.tcllibrary", TCL_VERSION, 0, maxPathLen, tclLibPath);
     }
     return foundInFramework;
 }
