@@ -424,18 +424,18 @@ EXTERN char *		TixGetStringFromObj _ANSI_ARGS_((
  */
 
 EXTERN int   TixDItemParseProc _ANSI_ARGS_((ClientData clientData,
-		Tcl_Interp *interp, Tk_Window tkwin, Arg value,
+		Tcl_Interp *interp, Tk_Window tkwin, Tcl_Obj * value,
 		char *widRec, int offset));
 
-EXTERN Arg   TixDItemPrintProc _ANSI_ARGS_((
+EXTERN Tcl_Obj *   TixDItemPrintProc _ANSI_ARGS_((
 		ClientData clientData, Tk_Window tkwin, char *widRec,
 		int offset, Tcl_FreeProc **freeProcPtr));
 
 EXTERN int   TixDItemStyleParseProc _ANSI_ARGS_((ClientData clientData,
-		Tcl_Interp *interp, Tk_Window tkwin, Arg value,
+		Tcl_Interp *interp, Tk_Window tkwin, Tcl_Obj * value,
 		char *widRec, int offset));
 
-EXTERN Arg   TixDItemStylePrintProc _ANSI_ARGS_((
+EXTERN Tcl_Obj *   TixDItemStylePrintProc _ANSI_ARGS_((
 		ClientData clientData, Tk_Window tkwin, char *widRec,
 		int offset, Tcl_FreeProc **freeProcPtr));
 
